@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2011 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,10 +20,14 @@
 using System;
 using System.Collections.Generic;
 using System.Text;
+using System.Reflection;
+using System.Xml;
 using System.Xml.Serialization;
 using System.Diagnostics;
 
+using KeePass.UI;
 using KeePass.Util;
+using KeePass.Util.XmlSerialization;
 
 using KeePassLib.Serialization;
 using KeePassLib.Utility;
@@ -59,10 +63,14 @@ namespace KeePass.App.Configuration
 			}
 		}
 
-		private AceLogging m_aceLogging = new AceLogging();
+		private AceLogging m_aceLogging = null;
 		public AceLogging Logging
 		{
-			get { return m_aceLogging; }
+			get
+			{
+				if(m_aceLogging == null) m_aceLogging = new AceLogging();
+				return m_aceLogging;
+			}
 			set
 			{
 				if(value == null) throw new ArgumentNullException("value");
@@ -81,10 +89,14 @@ namespace KeePass.App.Configuration
 			}
 		}
 
-		private AceUI m_aceUI = new AceUI();
+		private AceUI m_aceUI = null;
 		public AceUI UI
 		{
-			get { return m_aceUI; }
+			get
+			{
+				if(m_aceUI == null) m_aceUI = new AceUI();
+				return m_aceUI;
+			}
 			set
 			{
 				if(value == null) throw new ArgumentNullException("value");
@@ -92,10 +104,14 @@ namespace KeePass.App.Configuration
 			}
 		}
 
-		private AceSecurity m_sec = new AceSecurity();
+		private AceSecurity m_sec = null;
 		public AceSecurity Security
 		{
-			get { return m_sec; }
+			get
+			{
+				if(m_sec == null) m_sec = new AceSecurity();
+				return m_sec;
+			}
 			set
 			{
 				if(value == null) throw new ArgumentNullException("value");
@@ -103,10 +119,14 @@ namespace KeePass.App.Configuration
 			}
 		}
 
-		private AceNative m_native =  new AceNative();
+		private AceNative m_native = null;
 		public AceNative Native
 		{
-			get { return m_native; }
+			get
+			{
+				if(m_native == null) m_native = new AceNative();
+				return m_native;
+			}
 			set
 			{
 				if(value == null) throw new ArgumentNullException("value");
@@ -114,10 +134,14 @@ namespace KeePass.App.Configuration
 			}
 		}
 
-		private AcePasswordGenerator m_pwGen = new AcePasswordGenerator();
+		private AcePasswordGenerator m_pwGen = null;
 		public AcePasswordGenerator PasswordGenerator
 		{
-			get { return m_pwGen; }
+			get
+			{
+				if(m_pwGen == null) m_pwGen = new AcePasswordGenerator();
+				return m_pwGen;
+			}
 			set
 			{
 				if(value == null) throw new ArgumentNullException("value");
@@ -178,6 +202,8 @@ namespace KeePass.App.Configuration
 		/// </summary>
 		private void PrepareSave()
 		{
+			m_meta.OmitItemsWithDefaultValues = true;
+
 			m_aceApp.LastUsedFile.ClearCredentials(true);
 
 			foreach(IOConnectionInfo iocMru in m_aceApp.MostRecentlyUsed.Items)
@@ -187,11 +213,13 @@ namespace KeePass.App.Configuration
 				m_def.KeySources.Clear();
 
 			m_aceApp.TriggerSystem = Program.TriggerSystem;
+
+			SearchUtil.PrepareForSerialize(m_def.SearchParameters);
 		}
 
 		internal void OnLoad()
 		{
-			m_int.UrlSchemeOverrides.SetDefaultsIfEmpty();
+			// m_int.UrlSchemeOverrides.SetDefaultsIfEmpty();
 
 			ObfuscateCred(false);
 			ChangePathsRelAbs(true);
@@ -206,6 +234,8 @@ namespace KeePass.App.Configuration
 					vColumns.RemoveAt(i);
 				else ++i;
 			}
+
+			SearchUtil.FinishDeserialize(m_def.SearchParameters);
 		}
 
 		internal void OnSavePre()
@@ -243,7 +273,11 @@ namespace KeePass.App.Configuration
 		{
 			if(ioc == null) { Debug.Assert(false); return; }
 
-			if(ioc.IsLocalFile() == false) return;
+			if(!ioc.IsLocalFile()) return;
+
+			// Update path separators for current system
+			if(!UrlUtil.IsUncPath(ioc.Path))
+				ioc.Path = UrlUtil.ConvertSeparators(ioc.Path);
 
 			string strBase = WinUtil.GetExecutable();
 			bool bIsAbs = UrlUtil.IsAbsolutePath(ioc.Path);
@@ -280,6 +314,55 @@ namespace KeePass.App.Configuration
 			if(bObf) m_int.ProxyPassword = StrUtil.Obfuscate(m_int.ProxyPassword);
 			else m_int.ProxyPassword = StrUtil.Deobfuscate(m_int.ProxyPassword);
 		}
+
+		private static Dictionary<object, string> m_dictXmlPathCache =
+			new Dictionary<object, string>();
+		public static bool IsOptionEnforced(object pContainer, PropertyInfo pi)
+		{
+			if(pContainer == null) { Debug.Assert(false); return false; }
+			if(pi == null) { Debug.Assert(false); return false; }
+
+			XmlDocument xdEnforced = AppConfigSerializer.EnforcedConfigXml;
+			if(xdEnforced == null) return false;
+
+			string strObjPath;
+			if(!m_dictXmlPathCache.TryGetValue(pContainer, out strObjPath))
+			{
+				strObjPath = XmlUtil.GetObjectXmlPath(Program.Config, pContainer);
+				if(string.IsNullOrEmpty(strObjPath)) { Debug.Assert(false); return false; }
+
+				m_dictXmlPathCache[pContainer] = strObjPath;
+			}
+
+			string strProp = XmlSerializerEx.GetXmlName(pi);
+			if(string.IsNullOrEmpty(strProp)) { Debug.Assert(false); return false; }
+
+			string strPre = strObjPath;
+			if(!strPre.EndsWith("/")) strPre += "/";
+			string strXPath = strPre + strProp;
+
+			XmlNode xn = xdEnforced.SelectSingleNode(strXPath);
+			return (xn != null);
+		}
+
+		public static bool IsOptionEnforced(object pContainer, string strPropertyName)
+		{
+			if(pContainer == null) { Debug.Assert(false); return false; }
+			if(string.IsNullOrEmpty(strPropertyName)) { Debug.Assert(false); return false; }
+
+			// To improve performance (avoid type queries), check here, too
+			XmlDocument xdEnforced = AppConfigSerializer.EnforcedConfigXml;
+			if(xdEnforced == null) return false;
+
+			Type tContainer = pContainer.GetType();
+			PropertyInfo pi = tContainer.GetProperty(strPropertyName);
+			return IsOptionEnforced(pContainer, pi);
+		}
+
+		public static void ClearXmlPathCache()
+		{
+			m_dictXmlPathCache.Clear();
+		}
 	}
 
 	public sealed class AceMeta
@@ -302,5 +385,16 @@ namespace KeePass.App.Configuration
 		//	get { return m_bIsEnforced; }
 		//	set { m_bIsEnforced = value; }
 		// }
+
+		private bool m_bOmitDefaultValues = true;
+		// Informational property only (like an XML comment);
+		// currently doesn't have any effect (the XmlSerializer
+		// always omits default values, independent of this
+		// property)
+		public bool OmitItemsWithDefaultValues
+		{
+			get { return m_bOmitDefaultValues; }
+			set { m_bOmitDefaultValues = value; }
+		}
 	}
 }
