@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2011 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -76,6 +76,7 @@ namespace KeePass.DataExchange.Formats
 			kdb.Save(msDataXml, pwExportInfo.DataGroup, Kdb4Format.PlainXml, slLogger);
 
 			byte[] pbData = msDataXml.ToArray();
+			msDataXml.Close();
 			MemoryStream msDataRead = new MemoryStream(pbData, false);
 			XmlReader xmlDataReader = XmlReader.Create(msDataRead);
 
@@ -90,6 +91,8 @@ namespace KeePass.DataExchange.Formats
 			XmlWriter xmlWriter = XmlWriter.Create(sOutput, xws);
 			xsl.Transform(xmlDataReader, xmlWriter);
 			xmlWriter.Close();
+			xmlDataReader.Close();
+			msDataRead.Close();
 
 			Array.Clear(pbData, 0, pbData.Length);
 			return true;
