@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2011 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ namespace KeePass.Forms
 	public partial class CharPickerForm : Form
 	{
 		private ProtectedString m_psWord = null;
-		private ProtectedString m_psSelected = new ProtectedString(false);
+		private ProtectedString m_psSelected = ProtectedString.Empty;
 
 		private SecureEdit m_secWord = new SecureEdit();
 		private List<Button> m_lButtons = new List<Button>();
@@ -50,6 +50,7 @@ namespace KeePass.Forms
 		private bool m_bSetForeground = false;
 		private uint m_uCharCount = 0;
 		private bool? m_bInitHide = null;
+		private int m_nBannerWidth = -1;
 
 		private Font m_fontChars = null;
 		private char m_chMaskChar = ((NativeLib.GetPlatformID() ==
@@ -192,8 +193,10 @@ namespace KeePass.Forms
 		{
 			string strTitle = KPRes.PickCharacters;
 			if(m_uCharCount > 0) strTitle += " (" + m_uCharCount.ToString() + ")";
-			BannerFactory.CreateBannerEx(this, m_bannerImage,
-				Properties.Resources.B48x48_KGPG_Key2, strTitle, KPRes.PickCharactersDesc);
+
+			BannerFactory.UpdateBanner(this, m_bannerImage,
+				Properties.Resources.B48x48_KGPG_Key2, strTitle,
+				KPRes.PickCharactersDesc, ref m_nBannerWidth);
 
 			RemoveAllCharButtons();
 
