@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2011 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ namespace KeePass.Forms
 
 		public static byte[] CollectEntropyIfEnabled(PwProfile pp)
 		{
-			if(pp.CollectUserEntropy == false) return null;
+			if(!pp.CollectUserEntropy) return null;
 
 			EntropyForm ef = new EntropyForm();
 			if(UIUtil.ShowDialogNotValue(ef, DialogResult.OK)) return null;
