@@ -364,9 +364,9 @@
 			this.m_cbExpire.AutoSize = true;
 			this.m_cbExpire.Location = new System.Drawing.Point(360, 42);
 			this.m_cbExpire.Name = "m_cbExpire";
-			this.m_cbExpire.Size = new System.Drawing.Size(94, 17);
+			this.m_cbExpire.Size = new System.Drawing.Size(76, 17);
 			this.m_cbExpire.TabIndex = 8;
-			this.m_cbExpire.Text = "Expiration time";
+			this.m_cbExpire.Text = "Expiry time";
 			this.m_cbExpire.UseVisualStyleBackColor = true;
 			// 
 			// m_cbNotes
@@ -505,7 +505,7 @@
 			this.m_btnOK.Name = "m_btnOK";
 			this.m_btnOK.Size = new System.Drawing.Size(75, 23);
 			this.m_btnOK.TabIndex = 0;
-			this.m_btnOK.Text = "&Print";
+			this.m_btnOK.Text = "&Print...";
 			this.m_btnOK.UseVisualStyleBackColor = true;
 			this.m_btnOK.Click += new System.EventHandler(this.OnBtnOK);
 			// 
