@@ -78,7 +78,10 @@ namespace KeePass.Forms
 		private bool m_bForceClosing = false;
 
 		private PwInputControlGroup m_icgPassword = new PwInputControlGroup();
+		private ExpiryControlGroup m_cgExpiry = new ExpiryControlGroup();
 		private RichTextBoxContextMenu m_ctxNotes = new RichTextBoxContextMenu();
+		private Image m_imgPwGen = null;
+		private Image m_imgStdExpire = null;
 
 		private readonly string DeriveFromPrevious = "(" + KPRes.GenPwBasedOnPrevious + ")";
 		private DynamicMenu m_dynGenProfiles;
@@ -136,6 +139,11 @@ namespace KeePass.Forms
 			get { return m_ctxStrMoveToStandard; }
 		}
 
+		public ContextMenuStrip AttachmentsContextMenu
+		{
+			get { return m_ctxBinAttach; }
+		}
+
 		private bool m_bInitSwitchToHistory = false;
 		internal bool InitSwitchToHistoryTab
 		{
@@ -153,6 +161,7 @@ namespace KeePass.Forms
 			Program.Translation.ApplyTo("KeePass.Forms.PwEntryForm.m_ctxListOperations", m_ctxListOperations.Items);
 			Program.Translation.ApplyTo("KeePass.Forms.PwEntryForm.m_ctxPwGen", m_ctxPwGen.Items);
 			Program.Translation.ApplyTo("KeePass.Forms.PwEntryForm.m_ctxStrMoveToStandard", m_ctxStrMoveToStandard.Items);
+			Program.Translation.ApplyTo("KeePass.Forms.PwEntryForm.m_ctxBinAttach", m_ctxBinAttach.Items);
 		}
 
 		public void InitEx(PwEntry pwEntry, PwEditMode pwMode, PwDatabase pwDatabase,
@@ -204,9 +213,6 @@ namespace KeePass.Forms
 				m_tbRepeatPassword, m_lblQuality, m_pbQuality, m_lblQualityBitsText,
 				this, bHideInitial, false);
 
-			m_dtExpireDateTime.CustomFormat = DateTimeFormatInfo.CurrentInfo.ShortDatePattern +
-				" " + DateTimeFormatInfo.CurrentInfo.LongTimePattern;
-
 			if(m_pwEntry.Expires)
 			{
 				m_dtExpireDateTime.Value = m_pwEntry.ExpiryTime;
@@ -214,9 +220,10 @@ namespace KeePass.Forms
 			}
 			else // Does not expire
 			{
-				m_dtExpireDateTime.Value = DateTime.Now;
+				m_dtExpireDateTime.Value = DateTime.Now.Date;
 				m_cbExpires.Checked = false;
 			}
+			m_cgExpiry.Attach(m_cbExpires, m_dtExpireDateTime);
 
 			if(m_pwEditMode == PwEditMode.ViewReadOnlyEntry)
 			{
@@ -256,9 +263,9 @@ namespace KeePass.Forms
 			m_lvStrings.Columns.Add(KPRes.FieldName, nWidth);
 			m_lvStrings.Columns.Add(KPRes.FieldValue, nWidth);
 
-			nWidth = m_lvBinaries.ClientRectangle.Width;
+			nWidth = m_lvBinaries.ClientRectangle.Width / 2;
 			m_lvBinaries.Columns.Add(KPRes.Attachments, nWidth);
-			// m_lvBinaries.Columns.Add(KPRes.FieldValue, nWidth);
+			m_lvBinaries.Columns.Add(KPRes.Size, nWidth, HorizontalAlignment.Right);
 
 			if(m_pwEditMode == PwEditMode.ViewReadOnlyEntry)
 			{
@@ -266,6 +273,8 @@ namespace KeePass.Forms
 					m_btnStrDelete.Enabled = m_btnStrMove.Enabled =
 					m_btnBinAdd.Enabled = m_btnBinDelete.Enabled =
 					m_btnBinView.Enabled = m_btnBinSave.Enabled = false;
+
+				m_lvBinaries.LabelEdit = false;
 			}
 		}
 
@@ -329,10 +338,16 @@ namespace KeePass.Forms
 		// Public for plugins
 		public void UpdateEntryBinaries(bool bGuiToInternal)
 		{
-			UpdateEntryBinaries(bGuiToInternal, false);
+			UpdateEntryBinaries(bGuiToInternal, false, null);
 		}
 
 		public void UpdateEntryBinaries(bool bGuiToInternal, bool bUpdateState)
+		{
+			UpdateEntryBinaries(bGuiToInternal, bUpdateState, null);
+		}
+
+		public void UpdateEntryBinaries(bool bGuiToInternal, bool bUpdateState,
+			string strFocusItem)
 		{
 			if(bGuiToInternal) { }
 			else // Internal to GUI
@@ -343,9 +358,22 @@ namespace KeePass.Forms
 				{
 					PwIcon pwIcon = (kvpBin.Value.IsProtected ?
 						m_pwObjectProtected : m_pwObjectPlainText);
-					m_lvBinaries.Items.Add(kvpBin.Key, (int)pwIcon);
+					ListViewItem lvi = m_lvBinaries.Items.Add(kvpBin.Key, (int)pwIcon);
+					lvi.SubItems.Add(StrUtil.FormatDataSizeKB(kvpBin.Value.Length));
 				}
 				UIUtil.SetTopVisibleItem(m_lvBinaries, iTopVisible);
+
+				if(strFocusItem != null)
+				{
+					ListViewItem lvi = m_lvBinaries.FindItemWithText(strFocusItem,
+						false, 0, false);
+					if(lvi != null)
+					{
+						m_lvBinaries.EnsureVisible(lvi.Index);
+						UIUtil.SetFocusedItem(m_lvBinaries, lvi, true);
+					}
+					else { Debug.Assert(false); }
+				}
 			}
 
 			if(bUpdateState) EnableControlsEx();
@@ -485,11 +513,13 @@ namespace KeePass.Forms
 		{
 			Debug.Assert(m_lvStrings.Columns.Count == 2);
 			int dx = m_lvStrings.ClientRectangle.Width;
-			m_lvStrings.Columns[0].Width = m_lvStrings.Columns[1].Width = dx / 2;
+			m_lvStrings.Columns[0].Width = dx / 2;
+			m_lvStrings.Columns[1].Width = dx / 2;
 
-			Debug.Assert(m_lvBinaries.Columns.Count == 1);
+			Debug.Assert(m_lvBinaries.Columns.Count == 2);
 			dx = m_lvBinaries.ClientRectangle.Width;
-			m_lvBinaries.Columns[0].Width = dx;
+			m_lvBinaries.Columns[0].Width = (dx * 4) / 5;
+			m_lvBinaries.Columns[1].Width = dx / 5;
 
 			Debug.Assert(m_lvAutoType.Columns.Count == 2);
 			dx = m_lvAutoType.ClientRectangle.Width;
@@ -553,14 +583,22 @@ namespace KeePass.Forms
 			this.Icon = Properties.Resources.KeePass;
 			this.Text = strTitle;
 
+			m_imgPwGen = UIUtil.CreateDropDownImage(Properties.Resources.B16x16_Key_New);
+			m_imgStdExpire = UIUtil.CreateDropDownImage(Properties.Resources.B16x16_History);
+
 			UIUtil.SetButtonImage(m_btnTools,
 				Properties.Resources.B16x16_Package_Settings, true);
-			UIUtil.SetButtonImage(m_btnStandardExpires,
-				Properties.Resources.B16x16_History, true);
+			UIUtil.SetButtonImage(m_btnGenPw, m_imgPwGen, true);
+			UIUtil.SetButtonImage(m_btnStandardExpires, m_imgStdExpire, true);
 
 			if(m_pwEditMode == PwEditMode.ViewReadOnlyEntry)
 				m_bLockEnabledState = true;
 
+			// UIUtil.SetExplorerTheme(m_lvStrings, true);
+			// UIUtil.SetExplorerTheme(m_lvBinaries, true);
+			// UIUtil.SetExplorerTheme(m_lvAutoType, true);
+			// UIUtil.SetExplorerTheme(m_lvHistory, true);
+
 			UIUtil.PrepareStandardMultilineControl(m_rtNotes, true, true);
 
 			m_bInitializing = true;
@@ -661,22 +699,23 @@ namespace KeePass.Forms
 			m_btnPickFgColor.Enabled = m_cbCustomForegroundColor.Checked;
 			m_btnPickBgColor.Enabled = m_cbCustomBackgroundColor.Checked;
 
+			bool bATEnabled = m_cbAutoTypeEnabled.Checked;
 			m_lvAutoType.Enabled = m_btnAutoTypeAdd.Enabled =
 				m_rbAutoTypeSeqInherit.Enabled = m_rbAutoTypeOverride.Enabled =
-				m_cbAutoTypeObfuscation.Enabled = m_cbAutoTypeEnabled.Checked;
+				m_cbAutoTypeObfuscation.Enabled = bATEnabled;
 
 			if(!m_rbAutoTypeOverride.Checked)
 				m_tbDefaultAutoTypeSeq.Enabled = m_btnAutoTypeEditDefault.Enabled = false;
 			else
 				m_tbDefaultAutoTypeSeq.Enabled = m_btnAutoTypeEditDefault.Enabled =
-					m_cbAutoTypeEnabled.Checked;
+					bATEnabled;
 
 			int nAutoTypeSel = m_lvAutoType.SelectedItems.Count;
 
 			if(m_pwEditMode != PwEditMode.ViewReadOnlyEntry)
 			{
-				m_btnAutoTypeEdit.Enabled = (nAutoTypeSel == 1);
-				m_btnAutoTypeDelete.Enabled = (nAutoTypeSel >= 1);
+				m_btnAutoTypeEdit.Enabled = (bATEnabled && (nAutoTypeSel == 1));
+				m_btnAutoTypeDelete.Enabled = (bATEnabled && (nAutoTypeSel >= 1));
 			}
 
 			int nAccumSel = nStringsSel + nBinSel + nAutoTypeSel;
@@ -725,8 +764,8 @@ namespace KeePass.Forms
 			peTarget.Tags.Clear();
 			foreach(string strTag in vNewTags) peTarget.AddTag(strTag);
 
-			peTarget.Expires = m_cbExpires.Checked;
-			if(peTarget.Expires) peTarget.ExpiryTime = m_dtExpireDateTime.Value;
+			peTarget.Expires = m_cgExpiry.Checked;
+			if(peTarget.Expires) peTarget.ExpiryTime = m_cgExpiry.Value;
 
 			UpdateEntryStrings(true, false);
 
@@ -738,10 +777,7 @@ namespace KeePass.Forms
 				AutoTypeObfuscationOptions.UseClipboard :
 				AutoTypeObfuscationOptions.None);
 
-			if(m_rbAutoTypeSeqInherit.Checked) m_atConfig.DefaultSequence = string.Empty;
-			else if(m_rbAutoTypeOverride.Checked)
-				m_atConfig.DefaultSequence = m_tbDefaultAutoTypeSeq.Text;
-			else { Debug.Assert(false); }
+			SaveDefaultSeq();
 
 			peTarget.AutoType = m_atConfig;
 
@@ -750,17 +786,24 @@ namespace KeePass.Forms
 
 			StrUtil.NormalizeNewLines(peTarget.Strings, true);
 
+			bool bUndoBackup = false;
 			PwCompareOptions cmpOpt = m_cmpOpt;
 			if(bCreateBackup) cmpOpt |= PwCompareOptions.IgnoreLastBackup;
-
 			if(peTarget.EqualsEntry(m_pwInitialEntry, cmpOpt, MemProtCmpMode.CustomOnly))
 			{
+				// No modifications at all => restore last mod time and undo backup
 				peTarget.LastModificationTime = m_pwInitialEntry.LastModificationTime;
-
-				if(bCreateBackup)
-					peTarget.History.Remove(peTarget.History.GetAt(
-						peTarget.History.UCount - 1)); // Undo backup
+				bUndoBackup = bCreateBackup;
 			}
+			else if(bCreateBackup)
+			{
+				// If only history items have been modified (deleted) => undo
+				// backup, but without restoring the last mod time
+				PwCompareOptions cmpOptNH = (m_cmpOpt | PwCompareOptions.IgnoreHistory);
+				if(peTarget.EqualsEntry(m_pwInitialEntry, cmpOptNH, MemProtCmpMode.CustomOnly))
+					bUndoBackup = true;
+			}
+			if(bUndoBackup) peTarget.History.RemoveAt(peTarget.History.UCount - 1);
 
 			peTarget.MaintainBackups(m_pwDatabase);
 
@@ -769,6 +812,15 @@ namespace KeePass.Forms
 			return true;
 		}
 
+		private void SaveDefaultSeq()
+		{
+			if(m_rbAutoTypeSeqInherit.Checked)
+				m_atConfig.DefaultSequence = string.Empty;
+			else if(m_rbAutoTypeOverride.Checked)
+				m_atConfig.DefaultSequence = m_tbDefaultAutoTypeSeq.Text;
+			else { Debug.Assert(false); }
+		}
+
 		private void OnBtnOK(object sender, EventArgs e)
 		{
 			if(SaveEntry(m_pwEntry, true)) m_bForceClosing = true;
@@ -796,6 +848,14 @@ namespace KeePass.Forms
 
 			m_ctxNotes.Detach();
 			m_icgPassword.Release();
+			m_cgExpiry.Release();
+
+			m_btnGenPw.Image = null;
+			m_imgPwGen.Dispose();
+			m_imgPwGen = null;
+			m_btnStandardExpires.Image = null;
+			m_imgStdExpire.Dispose();
+			m_imgStdExpire = null;
 		}
 
 		private void OnBtnStrAdd(object sender, EventArgs e)
@@ -854,72 +914,7 @@ namespace KeePass.Forms
 
 		private void OnBtnBinAdd(object sender, EventArgs e)
 		{
-			if(m_pwEditMode == PwEditMode.ViewReadOnlyEntry) return;
-
-			OpenFileDialog ofd = UIUtil.CreateOpenFileDialog(KPRes.AttachFiles,
-				UIUtil.CreateFileTypeFilter(null, null, true), 1, null, true, true);
-
-			if(ofd.ShowDialog() == DialogResult.OK)
-			{
-				UpdateEntryBinaries(true, false);
-
-				foreach(string strFile in ofd.FileNames)
-				{
-					byte[] vBytes = null;
-					string strMsg, strItem = UrlUtil.GetFileName(strFile);
-
-					if(m_vBinaries.Get(strItem) != null)
-					{
-						strMsg = KPRes.AttachedExistsAlready + MessageService.NewLine +
-							strItem + MessageService.NewParagraph + KPRes.AttachNewRename +
-							MessageService.NewParagraph + KPRes.AttachNewRenameRemarks0 +
-							MessageService.NewLine + KPRes.AttachNewRenameRemarks1 +
-							MessageService.NewLine + KPRes.AttachNewRenameRemarks2;
-
-						DialogResult dr = MessageService.Ask(strMsg, null,
-							MessageBoxButtons.YesNoCancel);
-
-						if(dr == DialogResult.Cancel) continue;
-						else if(dr == DialogResult.Yes)
-						{
-							string strFileName = UrlUtil.StripExtension(strItem);
-							string strExtension = "." + UrlUtil.GetExtension(strItem);
-
-							int nTry = 0;
-							while(true)
-							{
-								string strNewName = strFileName + nTry.ToString() + strExtension;
-								if(m_vBinaries.Get(strNewName) == null)
-								{
-									strItem = strNewName;
-									break;
-								}
-
-								++nTry;
-							}
-						}
-					}
-
-					try
-					{
-						vBytes = File.ReadAllBytes(strFile);
-						vBytes = DataEditorForm.ConvertAttachment(strItem, vBytes);
-
-						if(vBytes != null)
-						{
-							ProtectedBinary pb = new ProtectedBinary(false, vBytes);
-							m_vBinaries.Set(strItem, pb);
-						}
-					}
-					catch(Exception exAttach)
-					{
-						MessageService.ShowWarning(KPRes.AttachFailed, strFile, exAttach);
-					}
-				}
-
-				UpdateEntryBinaries(false, true);
-				ResizeColumnHeaders();
-			}
+			m_ctxBinAttach.Show(m_btnBinAdd, new Point(0, m_btnBinAdd.Height));
 		}
 
 		private void OnBtnBinDelete(object sender, EventArgs e)
@@ -1002,7 +997,7 @@ namespace KeePass.Forms
 			if(m_pwEditMode == PwEditMode.ViewReadOnlyEntry) return;
 
 			EditAutoTypeItemForm dlg = new EditAutoTypeItemForm();
-			dlg.InitEx(m_atConfig, m_vStrings, -1, false);
+			dlg.InitEx(m_atConfig, -1, false, m_tbDefaultAutoTypeSeq.Text, m_vStrings);
 
 			if(UIUtil.ShowDialogAndDestroy(dlg) == DialogResult.OK)
 			{
@@ -1015,12 +1010,12 @@ namespace KeePass.Forms
 		{
 			if(m_pwEditMode == PwEditMode.ViewReadOnlyEntry) return;
 
-			EditAutoTypeItemForm dlg = new EditAutoTypeItemForm();
-
 			ListView.SelectedIndexCollection lvSel = m_lvAutoType.SelectedIndices;
 			Debug.Assert(lvSel.Count == 1); if(lvSel.Count != 1) return;
 
-			dlg.InitEx(m_atConfig, m_vStrings, lvSel[0], false);
+			EditAutoTypeItemForm dlg = new EditAutoTypeItemForm();
+			dlg.InitEx(m_atConfig, lvSel[0], false, m_tbDefaultAutoTypeSeq.Text,
+				m_vStrings);
 
 			if(UIUtil.ShowDialogAndDestroy(dlg) == DialogResult.OK)
 				UpdateAutoTypeList();
@@ -1113,13 +1108,18 @@ namespace KeePass.Forms
 		{
 			if(m_pwEditMode == PwEditMode.ViewReadOnlyEntry) return;
 
-			DateTime dt = DateTime.Now;
-			if(nYears != 0) dt = dt.AddYears(nYears);
-			if(nMonths != 0) dt = dt.AddMonths(nMonths);
-			if(nDays != 0) dt = dt.AddDays(nDays);
+			DateTime dt = DateTime.Now.Date;
+			dt = dt.AddYears(nYears);
+			dt = dt.AddMonths(nMonths);
+			dt = dt.AddDays(nDays);
 
-			m_cbExpires.Checked = true;
-			m_dtExpireDateTime.Value = dt;
+			DateTime dtPrevTime = m_cgExpiry.Value;
+			dt = dt.AddHours(dtPrevTime.Hour);
+			dt = dt.AddMinutes(dtPrevTime.Minute);
+			dt = dt.AddSeconds(dtPrevTime.Second);
+
+			m_cgExpiry.Checked = true;
+			m_cgExpiry.Value = dt;
 
 			EnableControlsEx();
 		}
@@ -1227,10 +1227,10 @@ namespace KeePass.Forms
 		{
 			if(m_pwEditMode == PwEditMode.ViewReadOnlyEntry) return;
 
-			m_atConfig.DefaultSequence = m_tbDefaultAutoTypeSeq.Text;
+			SaveDefaultSeq();
 
 			EditAutoTypeItemForm ef = new EditAutoTypeItemForm();
-			ef.InitEx(m_atConfig, m_vStrings, -1, true);
+			ef.InitEx(m_atConfig, -1, true, m_tbDefaultAutoTypeSeq.Text, m_vStrings);
 
 			if(UIUtil.ShowDialogAndDestroy(ef) == DialogResult.OK)
 				m_tbDefaultAutoTypeSeq.Text = m_atConfig.DefaultSequence;
@@ -1318,12 +1318,6 @@ namespace KeePass.Forms
 			m_ctxStrMoveToStandard.Show(m_btnStrMove, 0, m_btnStrMove.Height);
 		}
 
-		private void OnExpireDateTimeChanged(object sender, EventArgs e)
-		{
-			m_cbExpires.Checked = true;
-			EnableControlsEx();
-		}
-
 		private void OnNotesLinkClicked(object sender, LinkClickedEventArgs e)
 		{
 			WinUtil.OpenUrl(e.LinkText, m_pwEntry);
@@ -1497,7 +1491,7 @@ namespace KeePass.Forms
 				{
 					m_vBinaries.Set(strDataItem, new ProtectedBinary(
 						pbinData.IsProtected, def.EditedBinaryData));
-					UpdateEntryBinaries(false, true);
+					UpdateEntryBinaries(false, true, strDataItem); // Update size
 				}
 
 				UIUtil.DestroyForm(def);
@@ -1609,7 +1603,16 @@ namespace KeePass.Forms
 			return base.ProcessDialogKey(keyData);
 		}
 
+		private bool m_bClosing = false; // Mono bug workaround
 		private void OnFormClosing(object sender, FormClosingEventArgs e)
+		{
+			if(m_bClosing) return;
+			m_bClosing = true;
+			HandleFormClosing(e);
+			m_bClosing = false;
+		}
+
+		private void HandleFormClosing(FormClosingEventArgs e)
 		{
 			bool bCancel = false;
 			if(!m_bForceClosing && (m_pwEditMode != PwEditMode.ViewReadOnlyEntry))
@@ -1654,5 +1657,127 @@ namespace KeePass.Forms
 		{
 			OnBtnHistoryView(sender, e);
 		}
+
+		private void OnCtxBinImport(object sender, EventArgs e)
+		{
+			if(m_pwEditMode == PwEditMode.ViewReadOnlyEntry) return;
+
+			OpenFileDialog ofd = UIUtil.CreateOpenFileDialog(KPRes.AttachFiles,
+				UIUtil.CreateFileTypeFilter(null, null, true), 1, null, true, true);
+
+			if(ofd.ShowDialog() == DialogResult.OK)
+			{
+				UpdateEntryBinaries(true, false);
+
+				foreach(string strFile in ofd.FileNames)
+				{
+					byte[] vBytes = null;
+					string strMsg, strItem = UrlUtil.GetFileName(strFile);
+
+					if(m_vBinaries.Get(strItem) != null)
+					{
+						strMsg = KPRes.AttachedExistsAlready + MessageService.NewLine +
+							strItem + MessageService.NewParagraph + KPRes.AttachNewRename +
+							MessageService.NewParagraph + KPRes.AttachNewRenameRemarks0 +
+							MessageService.NewLine + KPRes.AttachNewRenameRemarks1 +
+							MessageService.NewLine + KPRes.AttachNewRenameRemarks2;
+
+						DialogResult dr = MessageService.Ask(strMsg, null,
+							MessageBoxButtons.YesNoCancel);
+
+						if(dr == DialogResult.Cancel) continue;
+						else if(dr == DialogResult.Yes)
+						{
+							string strFileName = UrlUtil.StripExtension(strItem);
+							string strExtension = "." + UrlUtil.GetExtension(strItem);
+
+							int nTry = 0;
+							while(true)
+							{
+								string strNewName = strFileName + nTry.ToString() + strExtension;
+								if(m_vBinaries.Get(strNewName) == null)
+								{
+									strItem = strNewName;
+									break;
+								}
+
+								++nTry;
+							}
+						}
+					}
+
+					try
+					{
+						vBytes = File.ReadAllBytes(strFile);
+						vBytes = DataEditorForm.ConvertAttachment(strItem, vBytes);
+
+						if(vBytes != null)
+						{
+							ProtectedBinary pb = new ProtectedBinary(false, vBytes);
+							m_vBinaries.Set(strItem, pb);
+						}
+					}
+					catch(Exception exAttach)
+					{
+						MessageService.ShowWarning(KPRes.AttachFailed, strFile, exAttach);
+					}
+				}
+
+				UpdateEntryBinaries(false, true);
+				ResizeColumnHeaders();
+			}
+		}
+
+		private void OnCtxBinNew(object sender, EventArgs e)
+		{
+			if(m_pwEditMode == PwEditMode.ViewReadOnlyEntry) return;
+
+			string strName;
+			for(int i = 0; ; ++i)
+			{
+				strName = KPRes.New;
+				if(i >= 1) strName += " (" + i.ToString() + ")";
+				strName += ".rtf";
+
+				if(m_vBinaries.Get(strName) == null) break;
+			}
+
+			ProtectedBinary pb = new ProtectedBinary();
+			m_vBinaries.Set(strName, pb);
+			UpdateEntryBinaries(false, true, strName);
+			ResizeColumnHeaders();
+
+			ListViewItem lviNew = m_lvBinaries.FindItemWithText(strName,
+				false, 0, false);
+			if(lviNew != null) lviNew.BeginEdit();
+		}
+
+		private void OnBinAfterLabelEdit(object sender, LabelEditEventArgs e)
+		{
+			string strNew = e.Label;
+
+			e.CancelEdit = true; // In the case of success, we update it on our own
+
+			if(string.IsNullOrEmpty(strNew)) return;
+			if(m_pwEditMode == PwEditMode.ViewReadOnlyEntry) return;
+
+			int iItem = e.Item;
+			if((iItem < 0) || (iItem >= m_lvBinaries.Items.Count)) return;
+			string strOld = m_lvBinaries.Items[iItem].Text;
+			if(strNew == strOld) return;
+
+			if(m_vBinaries.Get(strNew) != null)
+			{
+				MessageService.ShowWarning(KPRes.FieldNameExistsAlready);
+				return;
+			}
+
+			ProtectedBinary pb = m_vBinaries.Get(strOld);
+			if(pb == null) { Debug.Assert(false); return; }
+			m_vBinaries.Remove(strOld);
+			m_vBinaries.Set(strNew, pb);
+
+			UpdateEntryBinaries(false, true, strNew);
+		}
 	}
 }
