@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2011 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -46,6 +46,10 @@ namespace KeePass.Native
 		internal static extern IntPtr SendMessageHDItem(IntPtr hWnd, int nMsg,
 			IntPtr wParam, ref HDITEM hdItem);
 
+		// [DllImport("User32.dll", EntryPoint = "SendMessage")]
+		// private static extern IntPtr SendMessageLVGroup(IntPtr hWnd, int nMsg,
+		//	IntPtr wParam, ref LVGROUP lvGroup);
+
 		[DllImport("User32.dll", SetLastError = true)]
 		internal static extern IntPtr SendMessageTimeout(IntPtr hWnd, int nMsg,
 			IntPtr wParam, IntPtr lParam, uint fuFlags, uint uTimeout,
@@ -77,6 +81,14 @@ namespace KeePass.Native
 		[DllImport("User32.dll", EntryPoint = "GetClassLongPtr")]
 		private static extern IntPtr GetClassLongPtr64(IntPtr hWnd, int nIndex);
 
+		[DllImport("User32.dll")]
+		[return: MarshalAs(UnmanagedType.Bool)]
+		internal static extern bool IsIconic(IntPtr hWnd);
+
+		[DllImport("User32.dll")]
+		[return: MarshalAs(UnmanagedType.Bool)]
+		internal static extern bool IsZoomed(IntPtr hWnd);
+
 		[DllImport("User32.dll", SetLastError = true)]
 		private static extern int GetWindowTextLength(IntPtr hWnd);
 
@@ -256,6 +268,13 @@ namespace KeePass.Native
 		[return: MarshalAs(UnmanagedType.Bool)]
 		internal static extern bool CloseHandle(IntPtr hObject);
 
+		[DllImport("Kernel32.dll", SetLastError = true, CharSet = CharSet.Auto)]
+		internal static extern uint GetFileAttributes(string lpFileName);
+
+		[DllImport("Kernel32.dll", SetLastError = true, CharSet = CharSet.Auto)]
+		[return: MarshalAs(UnmanagedType.Bool)]
+		internal static extern bool DeleteFile(string lpFileName);
+
 		[DllImport("Kernel32.dll", ExactSpelling = true, SetLastError = true)]
 		[return: MarshalAs(UnmanagedType.Bool)]
 		internal static extern bool DeviceIoControl(IntPtr hDevice, uint dwIoControlCode,
@@ -359,5 +378,10 @@ namespace KeePass.Native
 		[return: MarshalAs(UnmanagedType.Bool)]
 		internal static extern bool PlaySound(string pszSound, IntPtr hmod,
 			uint fdwSound);
+
+		[DllImport("Shell32.dll", CharSet = CharSet.Auto)]
+		internal static extern IntPtr ShellExecute(IntPtr hwnd,
+			string lpOperation, string lpFile, string lpParameters,
+			string lpDirectory, int nShowCmd);
 	}
 }
