@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2011 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -230,8 +230,7 @@ namespace KeePass.Plugins
 					if(bContent.HasValue)
 						throw new PlgxException(KLRes.FileCorrupted);
 
-					string strCached = PlgxCache.GetCacheFile(plgx.FileUuid, true,
-						false);
+					string strCached = PlgxCache.GetCacheFile(plgx, true, false);
 					if(!string.IsNullOrEmpty(strCached) && plgx.AllowCached)
 					{
 						strPluginPath = strCached;
@@ -427,14 +426,14 @@ namespace KeePass.Plugins
 			string strKP = Program.CommandLineArgs[AppDefs.CommandLineOptions.PlgxPrereqKP];
 			if(!string.IsNullOrEmpty(strKP))
 			{
-				ulong uKP = StrUtil.GetVersion(strKP);
+				ulong uKP = StrUtil.ParseVersion(strKP);
 				if(uKP != 0) WriteObject(bw, PlgxPrereqKP, MemUtil.UInt64ToBytes(uKP));
 			}
 
 			string strNet = Program.CommandLineArgs[AppDefs.CommandLineOptions.PlgxPrereqNet];
 			if(!string.IsNullOrEmpty(strNet))
 			{
-				ulong uNet = StrUtil.GetVersion(strNet);
+				ulong uNet = StrUtil.ParseVersion(strNet);
 				if(uNet != 0) WriteObject(bw, PlgxPrereqNet, MemUtil.UInt64ToBytes(uNet));
 			}
 
@@ -510,9 +509,8 @@ namespace KeePass.Plugins
 			}
 
 			CompilerParameters cp = plgx.CompilerParameters;
-			cp.OutputAssembly = UrlUtil.EnsureTerminatingSeparator(strTmpRoot,
-				false) + UrlUtil.GetFileName(PlgxCache.GetCacheFile(plgx.FileUuid,
-				false, false));
+			cp.OutputAssembly = UrlUtil.EnsureTerminatingSeparator(strTmpRoot, false) +
+				UrlUtil.GetFileName(PlgxCache.GetCacheFile(plgx, false, false));
 			cp.GenerateExecutable = false;
 			cp.GenerateInMemory = false;
 			cp.IncludeDebugInformation = false;
@@ -524,16 +522,46 @@ namespace KeePass.Plugins
 			CompileEmbeddedRes(plgx);
 			PrepareSourceFiles(plgx);
 
-			CompilerResults cr;
-			if(!CompileAssembly(plgx, out cr, null))
-				if(!CompileAssembly(plgx, out cr, "v3.5"))
-				{
-					if(Program.CommandLineArgs[
-						AppDefs.CommandLineOptions.SavePluginCompileRes] != null)
-						SaveCompilerResults(plgx, cr);
+			string[] vCompilers;
+			if(Environment.Version.Major >= 4)
+			{
+				vCompilers = new string[] {
+					null,
+					"v4", // Suggested in CodeDomProvider.CreateProvider doc
+					"v4.0", // Suggested in community content of the above
+					"v4.0.30319", // Deduced from file system
+					"v3.5"
+				};
+			}
+			else // <= 3.5
+			{
+				vCompilers = new string[] {
+					null, "v3.5",
+					"v4", // Suggested in CodeDomProvider.CreateProvider doc
+					"v4.0", // Suggested in community content of the above
+					"v4.0.30319" // Deduced from file system
+				};
+			}
 
-					throw new InvalidOperationException();
+			CompilerResults cr = null;
+			bool bCompiled = false;
+			for(int iCmp = 0; iCmp < vCompilers.Length; ++iCmp)
+			{
+				if(CompileAssembly(plgx, ref cr, vCompilers[iCmp]))
+				{
+					bCompiled = true;
+					break;
 				}
+			}
+
+			if(!bCompiled)
+			{
+				if(Program.CommandLineArgs[
+					AppDefs.CommandLineOptions.SavePluginCompileRes] != null)
+					SaveCompilerResults(plgx, cr);
+
+				throw new InvalidOperationException();
+			}
 
 			Program.TempFilesPool.Add(cr.PathToAssembly);
 
@@ -547,8 +575,31 @@ namespace KeePass.Plugins
 		}
 
 		private static bool CompileAssembly(PlgxPluginInfo plgx,
-			out CompilerResults cr, string strCompilerVersion)
+			ref CompilerResults cr, string strCompilerVersion)
 		{
+			const string StrCoreRef = "System.Core";
+			const string StrCoreDll = "System.Core.dll";
+			bool bHasCore = false, bCoreAdded = false;
+			foreach(string strAsm in plgx.CompilerParameters.ReferencedAssemblies)
+			{
+				if(UrlUtil.AssemblyEquals(strAsm, StrCoreRef))
+				{
+					bHasCore = true;
+					break;
+				}
+			}
+			if((strCompilerVersion != null) && strCompilerVersion.StartsWith(
+				"v", StrUtil.CaseIgnoreCmp))
+			{
+				ulong v = StrUtil.ParseVersion(strCompilerVersion.Substring(1));
+				if(!bHasCore && (v >= 0x0003000500000000UL))
+				{
+					plgx.CompilerParameters.ReferencedAssemblies.Add(StrCoreDll);
+					bCoreAdded = true;
+				}
+			}
+
+			bool bResult = false;
 			try
 			{
 				Dictionary<string, string> dictOpt = new Dictionary<string, string>();
@@ -571,17 +622,22 @@ namespace KeePass.Plugins
 				cr = cdp.CompileAssemblyFromFile(plgx.CompilerParameters,
 					plgx.SourceFiles.ToArray());
 
-				return ((cr.Errors == null) || !cr.Errors.HasErrors);
+				bResult = ((cr.Errors == null) || !cr.Errors.HasErrors);
 			}
 			catch(Exception) { }
 
-			cr = null;
-			return false;
+			if(bCoreAdded)
+				plgx.CompilerParameters.ReferencedAssemblies.Remove(StrCoreDll);
+
+			// cr = null; // Keep previous results for output
+			return bResult;
 		}
 
 		private static void SaveCompilerResults(PlgxPluginInfo plgx,
 			CompilerResults cr)
 		{
+			if(cr == null) { Debug.Assert(false); return; }
+
 			StringBuilder sb = new StringBuilder();
 			foreach(string strOut in cr.Output)
 			{
@@ -696,7 +752,7 @@ namespace KeePass.Plugins
 				str = StrUtil.ReplaceCaseInsensitive(str, @"{PLGX_CACHE_DIR}", strCacheDir);
 
 			// str = UrlUtil.ConvertSeparators(str);
-			str = SprEngine.Compile(str, false, null, null, false, false);
+			str = SprEngine.Compile(str, null);
 
 			string strApp, strArgs;
 			StrUtil.SplitCommandLine(str, out strApp, out strArgs);
