@@ -21,10 +21,13 @@ using System;
 using System.Collections.Generic;
 using System.Text;
 using System.Windows.Forms;
-using System.Diagnostics;
+using System.Drawing;
 using System.Reflection;
+using System.Diagnostics;
 
 using KeePass.App;
+using KeePass.App.Configuration;
+using KeePass.Util;
 
 using KeePassLib.Utility;
 
@@ -43,11 +46,57 @@ namespace KeePass.UI
 	{
 		private ListView m_lv;
 
-		private List<object> m_vObjects = new List<object>();
-		private List<PropertyInfo> m_vProperties = new List<PropertyInfo>();
-		private List<ListViewItem> m_vListViewItems = new List<ListViewItem>();
+		private List<ClviInfo> m_lItems = new List<ClviInfo>();
+		private List<CheckItemLink> m_lLinks = new List<CheckItemLink>();
 
-		private List<CheckItemLink> m_vLinks = new List<CheckItemLink>();
+		private bool m_bUseEnforcedConfig;
+
+		private sealed class ClviInfo
+		{
+			private object m_o; // Never null
+			public object Object { get { return m_o; } }
+
+			// private string m_strPropName; // Never null
+			// public string PropertyName { get { return m_strPropName; } }
+
+			private PropertyInfo m_pi; // Never null
+			public PropertyInfo PropertyInfo { get { return m_pi; } }
+
+			private ListViewItem m_lvi; // Never null
+			public ListViewItem ListViewItem { get { return m_lvi; } }
+
+			public bool PropertyValue
+			{
+				get { return (bool)m_pi.GetValue(m_o, null); }
+				set { m_pi.SetValue(m_o, value, null); }
+			}
+
+			private bool m_bReadOnly = false;
+			public bool ReadOnly
+			{
+				get { return m_bReadOnly; }
+				set { m_bReadOnly = value; }
+			}
+
+			public ClviInfo(object pContainer, string strPropertyName,
+				ListViewItem lvi)
+			{
+				if(pContainer == null) throw new ArgumentNullException("pContainer");
+				if(strPropertyName == null) throw new ArgumentNullException("strPropertyName");
+				if(strPropertyName.Length == 0) throw new ArgumentException("strPropertyName");
+				// if(lvi == null) throw new ArgumentNullException("lvi");
+
+				m_o = pContainer;
+				// m_strPropName = strPropertyName;
+				m_lvi = lvi;
+
+				Type t = pContainer.GetType();
+				m_pi = t.GetProperty(strPropertyName);
+				if((m_pi == null) || (m_pi.PropertyType != typeof(bool)) ||
+					!m_pi.CanRead || !m_pi.CanWrite)
+					throw new ArgumentException("strPropertyName");
+			}
+		}
 
 		private sealed class CheckItemLink
 		{
@@ -69,11 +118,24 @@ namespace KeePass.UI
 			}
 		}
 
+		[Obsolete]
 		public CheckedLVItemDXList(ListView lv)
+		{
+			Construct(lv, false);
+		}
+
+		public CheckedLVItemDXList(ListView lv, bool bUseEnforcedConfig)
+		{
+			Construct(lv, bUseEnforcedConfig);
+		}
+
+		private void Construct(ListView lv, bool bUseEnforcedConfig)
 		{
 			if(lv == null) throw new ArgumentNullException("lv");
 
 			m_lv = lv;
+			m_bUseEnforcedConfig = bUseEnforcedConfig;
+
 			m_lv.ItemChecked += this.OnItemCheckedChanged;
 		}
 
@@ -88,10 +150,8 @@ namespace KeePass.UI
 		{
 			if(m_lv == null) { Debug.Assert(false); return; }
 
-			m_vObjects.Clear();
-			m_vProperties.Clear();
-			m_vListViewItems.Clear();
-			m_vLinks.Clear();
+			m_lItems.Clear();
+			m_lLinks.Clear();
 
 			m_lv.ItemChecked -= this.OnItemCheckedChanged;
 			m_lv = null;
@@ -101,21 +161,31 @@ namespace KeePass.UI
 		{
 			if(m_lv == null) { Debug.Assert(false); return; }
 
-			for(int i = 0; i < m_vObjects.Count; ++i)
-			{
-				object o = m_vObjects[i];
+			Color clr = SystemColors.ControlText;
+			float fH, fS, fV;
+			UIUtil.ColorToHsv(clr, out fH, out fS, out fV);
+			if(fV >= 0.5f) // Text color is rather light
+				clr = UIUtil.ColorFromHsv(fH, 0.0f, 0.40f);
+			else // Text color is rather dark
+				clr = UIUtil.ColorFromHsv(fH, 0.0f, 0.60f);
 
-				Debug.Assert(m_vListViewItems[i].Index >= 0);
-				Debug.Assert(m_lv.Items.IndexOf(m_vListViewItems[i]) >= 0);
+			foreach(ClviInfo clvi in m_lItems)
+			{
+				ListViewItem lvi = clvi.ListViewItem;
+
+				Debug.Assert(lvi.Index >= 0);
+				Debug.Assert(m_lv.Items.IndexOf(lvi) >= 0);
 				if(bGuiToInternals)
 				{
-					bool bChecked = m_vListViewItems[i].Checked;
-					m_vProperties[i].SetValue(o, bChecked, null);
+					bool bChecked = lvi.Checked;
+					clvi.PropertyValue = bChecked;
 				}
 				else // Internals to GUI
 				{
-					bool bValue = (bool)m_vProperties[i].GetValue(o, null);
-					m_vListViewItems[i].Checked = bValue;
+					bool bValue = clvi.PropertyValue;
+					lvi.Checked = bValue;
+
+					if(clvi.ReadOnly) lvi.ForeColor = clr;
 				}
 			}
 		}
@@ -125,18 +195,15 @@ namespace KeePass.UI
 		{
 			if(pContainer == null) throw new ArgumentNullException("pContainer");
 			if(strPropertyName == null) throw new ArgumentNullException("strPropertyName");
-			if(strPropertyName.Length == 0) throw new ArgumentException();
+			if(strPropertyName.Length == 0) throw new ArgumentException("strPropertyName");
 			if(strDisplayString == null) throw new ArgumentNullException("strDisplayString");
 
 			if(m_lv == null) { Debug.Assert(false); return null; }
 
-			Type t = pContainer.GetType();
-			PropertyInfo pi = t.GetProperty(strPropertyName);
-			if((pi == null) || (pi.PropertyType != typeof(bool)) ||
-				!pi.CanRead || !pi.CanWrite)
-				throw new ArgumentException();
-
 			ListViewItem lvi = new ListViewItem(strDisplayString);
+			ClviInfo clvi = new ClviInfo(pContainer, strPropertyName, lvi);
+			DetermineReadOnlyState(clvi);
+
 			if(lvgContainer != null)
 			{
 				lvi.Group = lvgContainer;
@@ -145,10 +212,7 @@ namespace KeePass.UI
 			}
 
 			m_lv.Items.Add(lvi);
-
-			m_vObjects.Add(pContainer);
-			m_vProperties.Add(pi);
-			m_vListViewItems.Add(lvi);
+			m_lItems.Add(clvi);
 
 			return lvi;
 		}
@@ -161,10 +225,22 @@ namespace KeePass.UI
 
 			if(m_lv == null) { Debug.Assert(false); return; }
 
-			Debug.Assert(m_vListViewItems.IndexOf(lviSource) >= 0);
-			Debug.Assert(m_vListViewItems.IndexOf(lviTarget) >= 0);
+			Debug.Assert(GetItem(lviSource) != null);
+			Debug.Assert(GetItem(lviTarget) != null);
 
-			m_vLinks.Add(new CheckItemLink(lviSource, lviTarget, t));
+			m_lLinks.Add(new CheckItemLink(lviSource, lviTarget, t));
+		}
+
+		private ClviInfo GetItem(ListViewItem lvi)
+		{
+			if(lvi == null) { Debug.Assert(false); return null; }
+
+			foreach(ClviInfo clvi in m_lItems)
+			{
+				if(clvi.ListViewItem == lvi) return clvi;
+			}
+
+			return null;
 		}
 
 		private void OnItemCheckedChanged(object sender, ItemCheckedEventArgs e)
@@ -174,8 +250,17 @@ namespace KeePass.UI
 
 			bool bChecked = lvi.Checked;
 
-			// Debug.Assert(m_vListViewItems.IndexOf(lvi) >= 0);
-			foreach(CheckItemLink cl in m_vLinks)
+			ClviInfo clvi = GetItem(lvi);
+			if(clvi != null)
+			{
+				if(clvi.ReadOnly && (bChecked != clvi.PropertyValue))
+				{
+					lvi.Checked = clvi.PropertyValue;
+					return;
+				}
+			}
+
+			foreach(CheckItemLink cl in m_lLinks)
 			{
 				if(cl.Source == lvi)
 				{
@@ -196,5 +281,15 @@ namespace KeePass.UI
 				}
 			}
 		}
+
+		private void DetermineReadOnlyState(ClviInfo clvi)
+		{
+			if(clvi == null) { Debug.Assert(false); return; }
+
+			if(!m_bUseEnforcedConfig) clvi.ReadOnly = false;
+			else
+				clvi.ReadOnly = AppConfigEx.IsOptionEnforced(clvi.Object,
+					clvi.PropertyInfo);
+		}
 	}
 }
