@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2011 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -219,6 +219,12 @@ namespace KeePassLib.Serialization
 
 		public static Stream OpenRead(IOConnectionInfo ioc)
 		{
+			if(StrUtil.IsDataUri(ioc.Path))
+			{
+				byte[] pbData = StrUtil.DataUriToData(ioc.Path);
+				if(pbData != null) return new MemoryStream(pbData, false);
+			}
+
 			if(ioc.IsLocalFile()) return OpenReadLocal(ioc);
 
 			return CreateWebClient(ioc).OpenRead(new Uri(ioc.Path));
@@ -243,7 +249,16 @@ namespace KeePassLib.Serialization
 
 			if(ioc.IsLocalFile()) return OpenWriteLocal(ioc);
 
-			return CreateWebClient(ioc).OpenWrite(new Uri(ioc.Path));
+			Uri uri = new Uri(ioc.Path);
+
+			// Mono does not set HttpWebRequest.Method to POST for writes,
+			// so one needs to set the method to PUT explicitly
+			if(NativeLib.IsUnix() && (uri.Scheme.Equals(Uri.UriSchemeHttp,
+				StrUtil.CaseIgnoreCmp) || uri.Scheme.Equals(Uri.UriSchemeHttps,
+				StrUtil.CaseIgnoreCmp)))
+				return CreateWebClient(ioc).OpenWrite(uri, WebRequestMethods.Http.Put);
+
+			return CreateWebClient(ioc).OpenWrite(uri);
 		}
 #else
 		public static Stream OpenWrite(IOConnectionInfo ioc)
@@ -275,7 +290,7 @@ namespace KeePassLib.Serialization
 				if(s == null) throw new FileNotFoundException();
 
 				// For FTP clients we called RETR to get the file, but we never
-				// followed-up and downloaded the file. Close may produce a
+				// followed-up and downloaded the file; close may produce a
 				// 550 error -- that's okay
 				try { s.Close(); }
 				catch(Exception) { }
@@ -306,7 +321,7 @@ namespace KeePassLib.Serialization
 				}
 				else req.Method = WrmDeleteFile;
 
-				req.GetResponse();
+				DisposeResponse(req.GetResponse(), true);
 			}
 #endif
 		}
@@ -350,7 +365,7 @@ namespace KeePassLib.Serialization
 					req.Headers.Set(WrhMoveFileTo, iocTo.Path);
 				}
 
-				req.GetResponse();
+				DisposeResponse(req.GetResponse(), true);
 			}
 #endif
 
@@ -366,5 +381,47 @@ namespace KeePassLib.Serialization
 			// }
 			// DeleteFile(iocFrom);
 		}
+
+		private static void DisposeResponse(WebResponse wr, bool bGetStream)
+		{
+			if(wr == null) return;
+
+			try
+			{
+				if(bGetStream)
+				{
+					Stream s = wr.GetResponseStream();
+					if(s != null) s.Close();
+				}
+			}
+			catch(Exception) { Debug.Assert(false); }
+
+			try { wr.Close(); }
+			catch(Exception) { Debug.Assert(false); }
+		}
+
+		public static byte[] ReadFile(IOConnectionInfo ioc)
+		{
+			Stream sIn = null;
+			MemoryStream ms = null;
+			try
+			{
+				sIn = IOConnection.OpenRead(ioc);
+				if(sIn == null) return null;
+
+				ms = new MemoryStream();
+				MemUtil.CopyStream(sIn, ms);
+
+				return ms.ToArray();
+			}
+			catch(Exception) { }
+			finally
+			{
+				if(sIn != null) sIn.Close();
+				if(ms != null) ms.Close();
+			}
+
+			return null;
+		}
 	}
 }
