@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2011 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -87,15 +87,28 @@ namespace KeePassLib.Serialization
 			ReadDocumentStreamed(CreateXmlReader(readerStream), sParentStream);
 		}
 
+		internal static XmlReaderSettings CreateStdXmlReaderSettings()
+		{
+			XmlReaderSettings xrs = new XmlReaderSettings();
+
+			xrs.CloseInput = true;
+			xrs.IgnoreComments = true;
+			xrs.IgnoreProcessingInstructions = true;
+			xrs.IgnoreWhitespace = true;
+
+#if !KeePassLibSD
+			xrs.ProhibitDtd = true;
+#endif
+
+			xrs.ValidationType = ValidationType.None;
+
+			return xrs;
+		}
+
 		private static XmlReader CreateXmlReader(Stream readerStream)
 		{
-			XmlReaderSettings xmlSettings = new XmlReaderSettings();
-			xmlSettings.CloseInput = true;
-			xmlSettings.IgnoreComments = true;
-			xmlSettings.IgnoreProcessingInstructions = true;
-			xmlSettings.IgnoreWhitespace = true;
-
-			return XmlReader.Create(readerStream, xmlSettings);
+			XmlReaderSettings xrs = CreateStdXmlReaderSettings();
+			return XmlReader.Create(readerStream, xrs);
 		}
 
 		private void ReadDocumentStreamed(XmlReader xr, Stream sParentStream)
@@ -105,19 +118,20 @@ namespace KeePassLib.Serialization
 
 			m_ctxGroups.Clear();
 			m_dictBinPool = new Dictionary<string, ProtectedBinary>();
-			m_dictBinPoolCopyOnRead = new Dictionary<string, ProtectedBinary>();
 
 			KdbContext ctx = KdbContext.Null;
 
 			uint uTagCounter = 0;
 
 			bool bSupportsStatus = (m_slLogger != null);
+			long lStreamLength = 1;
 			try
 			{
-				sParentStream.Position.ToString();
-				sParentStream.Length.ToString();
+				sParentStream.Position.ToString(); // Test Position support
+				lStreamLength = sParentStream.Length;
 			}
 			catch(Exception) { bSupportsStatus = false; }
+			if(lStreamLength <= 0) { Debug.Assert(false); lStreamLength = 1; }
 
 			m_bReadNextNode = true;
 
@@ -149,8 +163,17 @@ namespace KeePassLib.Serialization
 
 				++uTagCounter;
 				if(((uTagCounter % 256) == 0) && bSupportsStatus)
-					m_slLogger.SetProgress((uint)((sParentStream.Position * 100) /
-						sParentStream.Length));
+				{
+					Debug.Assert(lStreamLength == sParentStream.Length);
+					uint uPct = (uint)((sParentStream.Position * 100) /
+						lStreamLength);
+
+					// Clip percent value in case the stream reports incorrect
+					// position/length values (M120413)
+					if(uPct > 100) { Debug.Assert(false); uPct = 100; }
+
+					m_slLogger.SetProgress(uPct);
+				}
 			}
 
 			Debug.Assert(ctx == KdbContext.Null);
@@ -610,7 +633,9 @@ namespace KeePassLib.Serialization
 				return KdbContext.Entry;
 			else if((ctx == KdbContext.EntryAutoTypeItem) && (xr.Name == ElemAutoTypeItem))
 			{
-				m_ctxEntry.AutoType.Set(m_ctxATName, m_ctxATSeq);
+				AutoTypeAssociation atAssoc = new AutoTypeAssociation(m_ctxATName,
+					m_ctxATSeq);
+				m_ctxEntry.AutoType.Add(atAssoc);
 				m_ctxATName = null;
 				m_ctxATSeq = null;
 				return KdbContext.EntryAutoType;
@@ -637,10 +662,10 @@ namespace KeePassLib.Serialization
 		private string ReadString(XmlReader xr)
 		{
 			XorredBuffer xb = ProcessNode(xr);
-
 			if(xb != null)
 			{
 				byte[] pb = xb.ReadPlainText();
+				if(pb.Length == 0) return string.Empty;
 				return StrUtil.Utf8.GetString(pb, 0, pb.Length);
 			}
 
@@ -731,7 +756,17 @@ namespace KeePassLib.Serialization
 			XorredBuffer xb = ProcessNode(xr);
 			if(xb != null) return new ProtectedString(true, xb);
 
-			ProtectedString ps = new ProtectedString(false, ReadString(xr));
+			bool bProtect = false;
+			if(m_format == Kdb4Format.PlainXml)
+			{
+				if(xr.MoveToAttribute(AttrProtectedInMemPlainXml))
+				{
+					string strProtect = xr.Value;
+					bProtect = ((strProtect != null) && (strProtect == ValTrue));
+				}
+			}
+
+			ProtectedString ps = new ProtectedString(bProtect, ReadString(xr));
 			return ps;
 		}
 
@@ -761,7 +796,7 @@ namespace KeePassLib.Serialization
 			}
 
 			string strValue = ReadString(xr);
-			if(strValue.Length == 0) return new ProtectedBinary(false);
+			if(strValue.Length == 0) return new ProtectedBinary();
 
 			byte[] pbData = Convert.FromBase64String(strValue);
 			if(bCompressed) pbData = MemUtil.Decompress(pbData);
