@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2011 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -83,7 +83,7 @@ namespace KeePassLib.Serialization
 
 			HashingStreamEx hashedStream = new HashingStreamEx(sSaveTo, true, null);
 
-			UTF8Encoding encNoBom = new UTF8Encoding(false, false);
+			UTF8Encoding encNoBom = StrUtil.Utf8;
 			CryptoRandom cr = CryptoRandom.Instance;
 
 			try
@@ -418,22 +418,23 @@ namespace KeePassLib.Serialization
 				WriteObject(kvp.Key, kvp.Value, true);
 		}
 
-		private void WriteList(string name, AutoTypeConfig dictAutoType)
+		private void WriteList(string name, AutoTypeConfig cfgAutoType)
 		{
 			Debug.Assert(name != null);
-			Debug.Assert(dictAutoType != null);
-			if(dictAutoType == null) throw new ArgumentNullException("dictAutoType");
+			Debug.Assert(cfgAutoType != null);
+			if(cfgAutoType == null) throw new ArgumentNullException("cfgAutoType");
 
 			m_xmlWriter.WriteStartElement(name);
 
-			WriteObject(ElemAutoTypeEnabled, dictAutoType.Enabled);
-			WriteObject(ElemAutoTypeObfuscation, (int)dictAutoType.ObfuscationOptions);
+			WriteObject(ElemAutoTypeEnabled, cfgAutoType.Enabled);
+			WriteObject(ElemAutoTypeObfuscation, (int)cfgAutoType.ObfuscationOptions);
 
-			if(dictAutoType.DefaultSequence.Length > 0)
-				WriteObject(ElemAutoTypeDefaultSeq, dictAutoType.DefaultSequence, true);
+			if(cfgAutoType.DefaultSequence.Length > 0)
+				WriteObject(ElemAutoTypeDefaultSeq, cfgAutoType.DefaultSequence, true);
 
-			foreach(KeyValuePair<string, string> kvp in dictAutoType.WindowSequencePairs)
-				WriteObject(ElemAutoTypeItem, ElemWindow, ElemKeystrokeSequence, kvp);
+			foreach(AutoTypeAssociation a in cfgAutoType.Associations)
+				WriteObject(ElemAutoTypeItem, ElemWindow, ElemKeystrokeSequence,
+					new KeyValuePair<string, string>(a.WindowName, a.Sequence));
 
 			m_xmlWriter.WriteEndElement();
 		}
@@ -632,21 +633,25 @@ namespace KeePassLib.Serialization
 			m_xmlWriter.WriteEndElement();
 			m_xmlWriter.WriteStartElement(ElemValue);
 
+			bool bProtected = value.IsProtected;
 			if(bIsEntryString)
 			{
+				// Adjust memory protection setting (which might be different
+				// from the database default, e.g. due to an import which
+				// didn't specify the correct setting)
 				if(name == PwDefs.TitleField)
-					value.EnableProtection(m_pwDatabase.MemoryProtection.ProtectTitle);
+					bProtected = m_pwDatabase.MemoryProtection.ProtectTitle;
 				else if(name == PwDefs.UserNameField)
-					value.EnableProtection(m_pwDatabase.MemoryProtection.ProtectUserName);
+					bProtected = m_pwDatabase.MemoryProtection.ProtectUserName;
 				else if(name == PwDefs.PasswordField)
-					value.EnableProtection(m_pwDatabase.MemoryProtection.ProtectPassword);
+					bProtected = m_pwDatabase.MemoryProtection.ProtectPassword;
 				else if(name == PwDefs.UrlField)
-					value.EnableProtection(m_pwDatabase.MemoryProtection.ProtectUrl);
+					bProtected = m_pwDatabase.MemoryProtection.ProtectUrl;
 				else if(name == PwDefs.NotesField)
-					value.EnableProtection(m_pwDatabase.MemoryProtection.ProtectNotes);
+					bProtected = m_pwDatabase.MemoryProtection.ProtectNotes;
 			}
 
-			if(value.IsProtected && (m_format != Kdb4Format.PlainXml))
+			if(bProtected && (m_format != Kdb4Format.PlainXml))
 			{
 				m_xmlWriter.WriteAttributeString(AttrProtected, ValTrue);
 
@@ -695,6 +700,9 @@ namespace KeePassLib.Serialization
 					strValue = sb.ToString(); // Correct string for current code page
 				}
 
+				if((m_format == Kdb4Format.PlainXml) && bProtected)
+					m_xmlWriter.WriteAttributeString(AttrProtectedInMemPlainXml, ValTrue);
+
 				m_xmlWriter.WriteString(StrUtil.SafeXmlString(strValue));
 			}
 
@@ -798,7 +806,7 @@ namespace KeePassLib.Serialization
 			f.m_format = Kdb4Format.PlainXml;
 
 			XmlTextWriter xtw = null;
-			try { xtw = new XmlTextWriter(msOutput, new UTF8Encoding(false)); }
+			try { xtw = new XmlTextWriter(msOutput, StrUtil.Utf8); }
 			catch(Exception) { Debug.Assert(false); return false; }
 			if(xtw == null) { Debug.Assert(false); return false; }
 
