@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2011 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -111,6 +111,73 @@ namespace KeePassLib.Utility
 		}
 	}
 
+	public enum StrEncodingType
+	{
+		Unknown = 0,
+		Default,
+		Ascii,
+		Utf7,
+		Utf8,
+		Utf16LE,
+		Utf16BE,
+		Utf32LE,
+		Utf32BE
+	}
+
+	public sealed class StrEncodingInfo
+	{
+		private readonly StrEncodingType m_type;
+		public StrEncodingType Type
+		{
+			get { return m_type; }
+		}
+
+		private readonly string m_strName;
+		public string Name
+		{
+			get { return m_strName; }
+		}
+
+		private readonly Encoding m_enc;
+		public Encoding Encoding
+		{
+			get { return m_enc; }
+		}
+
+		private readonly uint m_cbCodePoint;
+		/// <summary>
+		/// Size of a character in bytes.
+		/// </summary>
+		public uint CodePointSize
+		{
+			get { return m_cbCodePoint; }
+		}
+
+		private readonly byte[] m_vSig;
+		/// <summary>
+		/// Start signature of the text (byte order mark).
+		/// May be <c>null</c> or empty, if no signature is known.
+		/// </summary>
+		public byte[] StartSignature
+		{
+			get { return m_vSig; }
+		}
+
+		public StrEncodingInfo(StrEncodingType t, string strName, Encoding enc,
+			uint cbCodePoint, byte[] vStartSig)
+		{
+			if(strName == null) throw new ArgumentNullException("strName");
+			if(enc == null) throw new ArgumentNullException("enc");
+			if(cbCodePoint <= 0) throw new ArgumentOutOfRangeException("cbCodePoint");
+
+			m_type = t;
+			m_strName = strName;
+			m_enc = enc;
+			m_cbCodePoint = cbCodePoint;
+			m_vSig = vStartSig;
+		}
+	}
+
 	/// <summary>
 	/// A class containing various string helper methods.
 	/// </summary>
@@ -135,11 +202,54 @@ namespace KeePassLib.Utility
 		{
 			get
 			{
-				if(m_encUtf8 == null) m_encUtf8 = new UTF8Encoding(false);
+				if(m_encUtf8 == null) m_encUtf8 = new UTF8Encoding(false, false);
 				return m_encUtf8;
 			}
 		}
 
+		private static List<StrEncodingInfo> m_lEncs = null;
+		public static IEnumerable<StrEncodingInfo> Encodings
+		{
+			get
+			{
+				if(m_lEncs == null)
+				{
+					m_lEncs = new List<StrEncodingInfo>();
+
+					m_lEncs.Add(new StrEncodingInfo(StrEncodingType.Default,
+#if !KeePassLibSD
+						Encoding.Default.EncodingName,
+#else
+						Encoding.Default.WebName,
+#endif
+						Encoding.Default,
+						(uint)Encoding.Default.GetBytes("a").Length, null));
+					m_lEncs.Add(new StrEncodingInfo(StrEncodingType.Ascii,
+						"ASCII", Encoding.ASCII, 1, null));
+					m_lEncs.Add(new StrEncodingInfo(StrEncodingType.Utf7,
+						"Unicode (UTF-7)", Encoding.UTF7, 1, null));
+					m_lEncs.Add(new StrEncodingInfo(StrEncodingType.Utf8,
+						"Unicode (UTF-8)", StrUtil.Utf8, 1, new byte[] { 0xEF, 0xBB, 0xBF }));
+					m_lEncs.Add(new StrEncodingInfo(StrEncodingType.Utf16LE,
+						"Unicode (UTF-16 LE)", new UnicodeEncoding(false, false),
+						2, new byte[] { 0xFF, 0xFE }));
+					m_lEncs.Add(new StrEncodingInfo(StrEncodingType.Utf16BE,
+						"Unicode (UTF-16 BE)", new UnicodeEncoding(true, false),
+						2, new byte[] { 0xFE, 0xFF }));
+#if !KeePassLibSD
+					m_lEncs.Add(new StrEncodingInfo(StrEncodingType.Utf32LE,
+						"Unicode (UTF-32 LE)", new UTF32Encoding(false, false),
+						4, new byte[] { 0xFF, 0xFE, 0x0, 0x0 }));
+					m_lEncs.Add(new StrEncodingInfo(StrEncodingType.Utf32BE,
+						"Unicode (UTF-32 BE)", new UTF32Encoding(true, false),
+						4, new byte[] { 0x0, 0x0, 0xFE, 0xFF }));
+#endif
+				}
+
+				return m_lEncs;
+			}
+		}
+
 		// public static string RtfPar
 		// {
 		//	// get { return (m_bRtl ? "\\rtlpar " : "\\par "); }
@@ -189,7 +299,7 @@ namespace KeePassLib.Utility
 			str = str.Replace("\"", @"&quot;");
 			str = str.Replace("\'", @"&#39;");
 
-			str = str.Replace("\r", string.Empty);
+			str = NormalizeNewLines(str, false);
 			str = str.Replace("\n", @"<br />");
 
 			return str;
@@ -602,7 +712,6 @@ namespace KeePassLib.Utility
 			for(char ch = 'A'; ch <= 'Z'; ++ch)
 			{
 				string strEnhAcc = @"(&" + ch.ToString() + @")";
-
 				if(str.IndexOf(strEnhAcc) >= 0)
 				{
 					str = str.Replace(@" " + strEnhAcc, string.Empty);
@@ -685,7 +794,7 @@ namespace KeePassLib.Utility
 		{
 			if(string.IsNullOrEmpty(str)) return false; // No assert
 
-			string s = str.ToLower().Trim();
+			string s = str.Trim().ToLower();
 			if(s == "true") return true;
 			if(s == "yes") return true;
 			if(s == "1") return true;
@@ -699,7 +808,7 @@ namespace KeePassLib.Utility
 		{
 			if(string.IsNullOrEmpty(str)) return null;
 
-			string s = str.ToLower().Trim();
+			string s = str.Trim().ToLower();
 			if(s == "true") return true;
 			if(s == "false") return false;
 
@@ -717,12 +826,50 @@ namespace KeePassLib.Utility
 			return "null";
 		}
 
-		public static string ToWindowsString(string str)
+		/// <summary>
+		/// Normalize new line characters in a string. Input strings may
+		/// contain mixed new line character sequences from all commonly
+		/// used operating systems (i.e. \r\n from Windows, \n from Unix
+		/// and \r from Mac OS.
+		/// </summary>
+		/// <param name="str">String with mixed new line characters.</param>
+		/// <param name="bWindows">If <c>true</c>, new line characters
+		/// are normalized for Windows (\r\n); if <c>false</c>, new line
+		/// characters are normalized for Unix (\n).</param>
+		/// <returns>String with normalized new line characters.</returns>
+		public static string NormalizeNewLines(string str, bool bWindows)
 		{
 			if(string.IsNullOrEmpty(str)) return str;
 
-			string strSingular = str.Replace("\r", string.Empty);
-			return strSingular.Replace("\n", "\r\n");
+			str = str.Replace("\r\n", "\n");
+			str = str.Replace("\r", "\n");
+
+			if(bWindows) str = str.Replace("\n", "\r\n");
+
+			return str;
+		}
+
+		private static char[] m_vNewLineChars = null;
+		public static void NormalizeNewLines(ProtectedStringDictionary dict,
+			bool bWindows)
+		{
+			if(dict == null) { Debug.Assert(false); return; }
+
+			if(m_vNewLineChars == null)
+				m_vNewLineChars = new char[]{ '\r', '\n' };
+
+			List<string> vKeys = dict.GetKeys();
+			foreach(string strKey in vKeys)
+			{
+				ProtectedString ps = dict.Get(strKey);
+				if(ps == null) { Debug.Assert(false); continue; }
+
+				string strValue = ps.ReadString();
+				if(strValue.IndexOfAny(m_vNewLineChars) < 0) continue;
+
+				dict.Set(strKey, new ProtectedString(ps.IsProtected,
+					NormalizeNewLines(strValue, bWindows)));
+			}
 		}
 
 		public static string AlphaNumericOnly(string str)
@@ -768,38 +915,73 @@ namespace KeePassLib.Utility
 		}
 
 		private static readonly char[] m_vVersionSep = new char[]{ '.', ',' };
-		public static ulong GetVersion(string strVersion)
+		public static ulong ParseVersion(string strVersion)
 		{
-			if(string.IsNullOrEmpty(strVersion)) { Debug.Assert(false); return 0; }
+			if(strVersion == null) { Debug.Assert(false); return 0; }
 
 			string[] vVer = strVersion.Split(m_vVersionSep);
 			if((vVer == null) || (vVer.Length == 0)) { Debug.Assert(false); return 0; }
 
 			ushort uPart;
-			StrUtil.TryParseUShort(vVer[0], out uPart);
+			StrUtil.TryParseUShort(vVer[0].Trim(), out uPart);
 			ulong uVer = ((ulong)uPart << 48);
 
 			if(vVer.Length >= 2)
 			{
-				StrUtil.TryParseUShort(vVer[1], out uPart);
+				StrUtil.TryParseUShort(vVer[1].Trim(), out uPart);
 				uVer |= ((ulong)uPart << 32);
 			}
 
 			if(vVer.Length >= 3)
 			{
-				StrUtil.TryParseUShort(vVer[2], out uPart);
+				StrUtil.TryParseUShort(vVer[2].Trim(), out uPart);
 				uVer |= ((ulong)uPart << 16);
 			}
 
 			if(vVer.Length >= 4)
 			{
-				StrUtil.TryParseUShort(vVer[3], out uPart);
+				StrUtil.TryParseUShort(vVer[3].Trim(), out uPart);
 				uVer |= (ulong)uPart;
 			}
 
 			return uVer;
 		}
 
+		public static string VersionToString(ulong uVersion)
+		{
+			return VersionToString(uVersion, false);
+		}
+
+		public static string VersionToString(ulong uVersion,
+			bool bEnsureAtLeastTwoComp)
+		{
+			string str = string.Empty;
+			bool bMultiComp = false;
+
+			for(int i = 0; i < 4; ++i)
+			{
+				ushort us = (ushort)(uVersion & 0xFFFFUL);
+
+				if((us != 0) || (str.Length > 0))
+				{
+					if(str.Length > 0)
+					{
+						str = "." + str;
+						bMultiComp = true;
+					}
+
+					str = us.ToString() + str;
+				}
+
+				uVersion >>= 16;
+			}
+
+			if(bEnsureAtLeastTwoComp && !bMultiComp && (str.Length > 0))
+				str += ".0";
+
+			return str;
+		}
+
 		private static readonly byte[] m_pbOptEnt = { 0xA5, 0x74, 0x2E, 0xEC };
 
 		public static string EncryptString(string strPlainText)
@@ -1001,7 +1183,7 @@ namespace KeePassLib.Utility
 			if(strMulti.Length == 0) return string.Empty;
 
 			string str = strMulti;
-			str = str.Replace("\r\n", "\n");
+			str = str.Replace("\r\n", " ");
 			str = str.Replace("\r", " ");
 			str = str.Replace("\n", " ");
 
@@ -1040,5 +1222,113 @@ namespace KeePassLib.Utility
 			if(x.Length == y.Length) return 0;
 			return ((x.Length > y.Length) ? -1 : 1);
 		}
+
+		public static bool IsDataUri(string strUri)
+		{
+			if(strUri == null) { Debug.Assert(false); return false; }
+
+			return strUri.StartsWith("data:", StrUtil.CaseIgnoreCmp);
+		}
+
+		/// <summary>
+		/// Create a data URI (according to RFC 2397).
+		/// </summary>
+		/// <param name="pbData">Data to encode.</param>
+		/// <param name="strMimeType">Optional MIME type. If <c>null</c>,
+		/// an appropriate type is used.</param>
+		/// <returns>Data URI.</returns>
+		public static string DataToDataUri(byte[] pbData, string strMimeType)
+		{
+			if(pbData == null) throw new ArgumentNullException("pbData");
+
+			if(strMimeType == null) strMimeType = "application/octet-stream";
+
+#if !KeePassLibSD
+			return ("data:" + strMimeType + ";base64," + Convert.ToBase64String(
+				pbData, Base64FormattingOptions.None));
+#else
+			return ("data:" + strMimeType + ";base64," + Convert.ToBase64String(
+				pbData));
+#endif
+		}
+
+		/// <summary>
+		/// Convert a data URI (according to RFC 2397) to binary data.
+		/// </summary>
+		/// <param name="strDataUri">Data URI to decode.</param>
+		/// <returns>Decoded binary data.</returns>
+		public static byte[] DataUriToData(string strDataUri)
+		{
+			if(strDataUri == null) throw new ArgumentNullException("strDataUri");
+			if(!strDataUri.StartsWith("data:", StrUtil.CaseIgnoreCmp)) return null;
+
+			int iSep = strDataUri.IndexOf(',');
+			if(iSep < 0) return null;
+
+			string strDesc = strDataUri.Substring(5, iSep - 5);
+			bool bBase64 = strDesc.EndsWith(";base64", StrUtil.CaseIgnoreCmp);
+
+			string strData = strDataUri.Substring(iSep + 1);
+
+			if(bBase64) return Convert.FromBase64String(strData);
+
+			MemoryStream ms = new MemoryStream();
+
+			string[] v = strData.Split('%');
+			byte[] pb = Encoding.ASCII.GetBytes(v[0]);
+			ms.Write(pb, 0, pb.Length);
+			for(int i = 1; i < v.Length; ++i)
+			{
+				ms.WriteByte(Convert.ToByte(v[i].Substring(0, 2), 16));
+				pb = Encoding.ASCII.GetBytes(v[i].Substring(2));
+				ms.Write(pb, 0, pb.Length);
+			}
+
+			pb = ms.ToArray();
+			ms.Close();
+			return pb;
+		}
+
+		/// <summary>
+		/// Remove placeholders from a string (wrapped in '{' and '}').
+		/// This doesn't remove environment variables (wrapped in '%').
+		/// </summary>
+		public static string RemovePlaceholders(string str)
+		{
+			if(str == null) { Debug.Assert(false); return string.Empty; }
+
+			while(true)
+			{
+				int iPlhStart = str.IndexOf('{');
+				if(iPlhStart < 0) break;
+
+				int iPlhEnd = str.IndexOf('}', iPlhStart); // '{' might be at end
+				if(iPlhEnd < 0) break;
+
+				str = (str.Substring(0, iPlhStart) + str.Substring(iPlhEnd + 1));
+			}
+
+			return str;
+		}
+
+		public static StrEncodingInfo GetEncoding(StrEncodingType t)
+		{
+			foreach(StrEncodingInfo sei in StrUtil.Encodings)
+			{
+				if(sei.Type == t) return sei;
+			}
+
+			return null;
+		}
+
+		public static StrEncodingInfo GetEncoding(string strName)
+		{
+			foreach(StrEncodingInfo sei in StrUtil.Encodings)
+			{
+				if(sei.Name == strName) return sei;
+			}
+
+			return null;
+		}
 	}
 }
